@@ -44,6 +44,10 @@ fi
     # Use the kolla-ansible tag rather than the kolla tag, since this is what
     # kolla-ansible will use by default.
     TAG=$(python -c "import pbr.version; print(pbr.version.VersionInfo('kolla-ansible'))")
+    if [[ $ACTION == "zun" ]]; then
+        GATE_IMAGES+=",zun,kuryr"
+    fi
+
     cat <<EOF | sudo tee /etc/kolla/kolla-build.conf
 [DEFAULT]
 include_header = /etc/kolla/header
@@ -91,6 +95,9 @@ function setup_ansible {
 
     # TODO(SamYaple): Move to virtualenv
     sudo -H pip install -U "ansible>=2,<2.4" "docker>=2.0.0" "python-openstackclient" "ara<0.16" "cmd2<0.9.0"
+    if [[ $ACTION == "zun" ]]; then
+        sudo -H pip install -U "python-zunclient"
+    fi
     detect_distro
 
     sudo mkdir /etc/ansible
@@ -139,6 +146,12 @@ function sanity_check {
         openstack volume create --size 2 test_volume
         openstack server add volume kolla_boot_test test_volume --device /dev/vdb
     fi
+    if echo $ACTION | grep -q "zun"; then
+        openstack --debug appcontainer service list
+        openstack --debug appcontainer host list
+        # TODO(hongbin): Run a Zun container and assert the container becomes
+        # Running
+    fi
 }
 
 check_failure() {
@@ -167,10 +180,6 @@ setup_node
 tools/kolla-ansible -i ${RAW_INVENTORY} bootstrap-servers > /tmp/logs/ansible/bootstrap-servers
 prepare_images
 
-if echo $ACTION | grep -q "ceph"; then
-    ansible-playbook -i ${RAW_INVENTORY} tests/ansible_setup_ceph_disks.yml > /tmp/logs/ansible/setup_ceph_disks
-fi
-
 # Create dummy interface for neutron
 ansible -m shell -i ${RAW_INVENTORY} -a "ip l a fake_interface type dummy" all
 
@@ -182,16 +191,20 @@ tools/kolla-ansible -i ${RAW_INVENTORY} -vvv prechecks > /tmp/logs/ansible/prech
 # service in CI
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv deploy > /tmp/logs/ansible/deploy
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv post-deploy > /tmp/logs/ansible/post-deploy
+tools/kolla-ansible -i ${RAW_INVENTORY} -vvv check > /tmp/logs/ansible/check-deploy
 
 # Test OpenStack Environment
 # TODO: use kolla-ansible check when it's ready
+
 sanity_check
 
 # TODO(jeffrey4l): make some configure file change and
 # trigger a real reconfigure
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv reconfigure >  /tmp/logs/ansible/post-deploy
+tools/kolla-ansible -i ${RAW_INVENTORY} -vvv check > /tmp/logs/ansible/check-reconfigure
 # TODO(jeffrey4l): need run a real upgrade
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv upgrade > /tmp/logs/ansible/upgrade
+tools/kolla-ansible -i ${RAW_INVENTORY} -vvv check > /tmp/logs/ansible/check-upgrade
 
 # run prechecks again
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv prechecks > /tmp/logs/ansible/prechecks2
